package cn.com.qmth.examcloud.service.examwork.api;

import cn.com.qmth.examcloud.service.examwork.dao.ExamStudentRepo;
import cn.com.qmth.examcloud.service.examwork.entity.ExamStudent;
import cn.com.qmth.examcloud.service.examwork.service.ExamStudentService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

/**
 * 考生服务API
 * Created by songyue on 17/1/13.
 */
@RestController
@RequestMapping("${app.api.root}")
public class ExamStudentApi {

    @Autowired
    ExamStudentRepo examStudentRepo;

    @Autowired
    ExamStudentService examStudentService;

    @ApiOperation(value="查询所有考试学生",notes = "分页")
    @GetMapping("/exam_student/all/{curPage}/{pageSize}")
    public ResponseEntity getAllExamStudent(@ModelAttribute ExamStudent examCriteria, @PathVariable Integer curPage, @PathVariable Integer pageSize){
        return examStudentService.getAllExamStudent(examCriteria,new PageRequest(curPage - 1,pageSize));
    }

    @ApiOperation(value="查询所有考试学生",notes = "不分页")
    @GetMapping("/exam_student/all")
    public ResponseEntity getAllExamStudent(@ModelAttribute ExamStudent examCriteria){
        return examStudentService.getAllExamStudent(examCriteria);
    }

    @ApiOperation(value="查询所有考试学生",notes = "不分页不带查询条件")
    @GetMapping("/exam_student")
    public ResponseEntity getAllExamStudent(){
        return new ResponseEntity(examStudentRepo.findAll(), HttpStatus.OK);
    }

    @ApiOperation(value="按ID查询考试学生",notes = "ID查询")
    @GetMapping("/exam_student/{id}")
    public ResponseEntity<ExamStudent> getExamStudentById(@PathVariable Long id){
        return examStudentService.getExamStudentById(id);
    }

    @ApiOperation(value="新增考试学生",notes = "新增")
    @PostMapping("/exam_student")
    public ResponseEntity addExamStudent(@RequestBody ExamStudent examStudent){
        return examStudentService.saveExamStudent(examStudent);
    }

    @ApiOperation(value="更新考试学生",notes = "更新")
    @PutMapping("/exam_student")
    public ResponseEntity updateExamStudent(@RequestBody ExamStudent examStudent){
        return examStudentService.saveExamStudent(examStudent);
    }

    @ApiOperation(value="按ID删除考试学生",notes = "删除")
    @DeleteMapping("/exam_student/{id}")
    public ResponseEntity deleteExamStudent(@PathVariable Long id){
        return examStudentService.deleteExamStudent(id);
    }
}
