package cn.com.qmth.examcloud.service.examwork.service;

import cn.com.qmth.examcloud.service.examwork.dao.ExamRepo;
import cn.com.qmth.examcloud.service.examwork.entity.Exam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

/**
 * 考试批次服务类
 * Created by songyue on 17/1/13.
 */
@Service
public class ExamService {
    @Autowired
    ExamRepo examRepo;

    /**
     * 获取所有考试批次(分页)
     * @param examCriteria
     * @param pageable
     * @return
     */
    public ResponseEntity getAllExam(Exam examCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<Exam> examExample = Example.of(examCriteria, exampleMatcher);
        return new ResponseEntity(examRepo.findAll(examExample,pageable), HttpStatus.OK);
    }

    /**
     * 获取所有考试批次
     * @param examCriteria
     * @return
     */
    public ResponseEntity getAllExam(Exam examCriteria){
//        ExampleMatcher exampleMatcher = ExampleMatcher.matching();
        Example<Exam> examExample = Example.of(examCriteria);
        return new ResponseEntity(examRepo.findAll(examExample), HttpStatus.OK);
    }

    /**
     * 获取所有考试批次
     * @return
     */
    public ResponseEntity getAllExam(){
        return new ResponseEntity(examRepo.findAll(), HttpStatus.OK);
    }

    /**
     * 按ID获取考试批次
     * @param examId
     * @return
     */
    public ResponseEntity<Exam> getExamById(Long examId){
        return new ResponseEntity<Exam>(examRepo.findOne(examId),HttpStatus.OK);
    }

    /**
     * 保存考试批次
     * @param exam
     * @return
     */
    public ResponseEntity saveExam(Exam exam){
        return new ResponseEntity(examRepo.save(exam),HttpStatus.OK);
    }

    /**
     * 删除考试批次
     * @param examId
     * @return
     */
    public ResponseEntity deleteExam(Long examId){
        examRepo.delete(examId);
        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 删除所有考试批次
     * @return
     */
    public ResponseEntity deleteAllExam(){
        examRepo.deleteAll();
        return new ResponseEntity(HttpStatus.OK);
    }
}
