package cn.com.qmth.examcloud.service.examwork.service;

import cn.com.qmth.examcloud.service.examwork.dao.ExamStudentRepo;
import cn.com.qmth.examcloud.service.examwork.entity.ExamStudent;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.ExampleMatcher;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import static org.springframework.data.domain.ExampleMatcher.GenericPropertyMatchers.startsWith;

/**
 * 考试学生服务类
 * Created by songyue on 17/1/14.
 */
@Service
public class ExamStudentService {
    @Autowired
    ExamStudentRepo examStudentRepo;

    /**
     * 获取所有考试学生(分页)
     * @param examCriteria
     * @param pageable
     * @return
     */
    public ResponseEntity getAllExamStudent(ExamStudent examCriteria, Pageable pageable){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<ExamStudent> examExamStudentple = Example.of(examCriteria, exampleMatcher);
        return new ResponseEntity(examStudentRepo.findAll(examExamStudentple,pageable), HttpStatus.OK);
    }

    /**
     * 获取所有考试学生
     * @param examCriteria
     * @return
     */
    public ResponseEntity getAllExamStudent(ExamStudent examCriteria){
        ExampleMatcher exampleMatcher = ExampleMatcher.matching()
                .withMatcher("name",startsWith());
        Example<ExamStudent> examExamStudentple = Example.of(examCriteria, exampleMatcher);
        return new ResponseEntity(examStudentRepo.findAll(examExamStudentple), HttpStatus.OK);
    }

    /**
     * 按ID获取考试学生
     * @param studentId
     * @return
     */
    public ResponseEntity<ExamStudent> getExamStudentById(Long studentId){
        return new ResponseEntity<ExamStudent>(examStudentRepo.findOne(studentId),HttpStatus.OK);
    }

    /**
     * 按考试批次获取学生
     * @param examId
     * @return
     */
    public ResponseEntity getExamStudentByExamId(Long examId,Pageable pageable){
        return new ResponseEntity(examStudentRepo.findByExamId(examId,pageable),HttpStatus.OK);
    }

    /**
     * 保存考试学生
     * @param exam
     * @return
     */
    public ResponseEntity saveExamStudent(ExamStudent exam){
        return new ResponseEntity(examStudentRepo.save(exam),HttpStatus.OK);
    }

    /**
     * 删除考试学生
     * @param examId
     * @return
     */
    public ResponseEntity deleteExamStudent(Long examId){
        examStudentRepo.delete(examId);
        return new ResponseEntity(HttpStatus.OK);
    }

    /**
     * 删除所有考试学生
     * @return
     */
    public ResponseEntity deleteAllExamStudent(){
        examStudentRepo.deleteAll();
        return new ResponseEntity(HttpStatus.OK);
    }
}
